@@ -8,7 +8,17 @@ use warnings;
 use Carp;
 use Encode ();
 use List::Util ();
-use PPIx::QuoteLike::Constant qw{ MINIMUM_PERL VARIABLE_RE };
+use PPIx::QuoteLike::Constant qw{
+    ARRAY_REF
+    LOCATION_LINE
+    LOCATION_CHARACTER
+    LOCATION_COLUMN
+    LOCATION_LOGICAL_LINE
+    LOCATION_LOGICAL_FILE
+    MINIMUM_PERL
+    VARIABLE_RE
+    @CARP_NOT
+};
 use PPIx::QuoteLike::Token::Control;
 use PPIx::QuoteLike::Token::Delimiter;
 use PPIx::QuoteLike::Token::Interpolation;
@@ -16,12 +26,29 @@ use PPIx::QuoteLike::Token::String;
 use PPIx::QuoteLike::Token::Structure;
 use PPIx::QuoteLike::Token::Unknown;
 use PPIx::QuoteLike::Token::Whitespace;
+use PPIx::QuoteLike::Utils qw{
+    column_number
+    line_number
+    logical_filename
+    logical_line_number
+    statement
+    visual_column_number
+    __instance
+};
 use Scalar::Util ();
+use Text::Tabs ();
 
-our $VERSION = '0.005';
+our $VERSION = '0.010';
 
-use constant ARRAY	=> ref [];
-use constant CODE	=> ref sub {};
+use constant CLASS_CONTROL       => 'PPIx::QuoteLike::Token::Control';
+use constant CLASS_DELIMITER     => 'PPIx::QuoteLike::Token::Delimiter';
+use constant CLASS_INTERPOLATION => 'PPIx::QuoteLike::Token::Interpolation';
+use constant CLASS_STRING        => 'PPIx::QuoteLike::Token::String';
+use constant CLASS_STRUCTURE     => 'PPIx::QuoteLike::Token::Structure';
+use constant CLASS_UNKNOWN       => 'PPIx::QuoteLike::Token::Unknown';
+use constant CLASS_WHITESPACE    => 'PPIx::QuoteLike::Token::Whitespace';
+
+use constant CODE_REF	=> ref sub {};
 
 use constant ILLEGAL_FIRST	=>
     'Tokenizer found illegal first characters';
@@ -43,10 +70,26 @@ $PPIx::QuoteLike::DEFAULT_POSTDEREF = 1;
 	defined $arg{postderef}
 	    or $arg{postderef} = $PPIx::QuoteLike::DEFAULT_POSTDEREF;
 
+	if ( $arg{location} ) {
+	    ARRAY_REF eq ref $arg{location}
+		or croak q<Argument 'location' must be an array reference>;
+	    foreach my $inx ( 0 .. 3 ) {
+		$arg{location}[$inx] =~ m/ [^0-9] /smx
+		    and croak "Argument 'location' element $inx must be an unsigned integer";
+	    }
+	}
+
+	if ( ! defined $arg{index_locations} ) {
+	    $arg{index_locations} = !! $arg{location} ||
+		__instance( $source, 'PPI::Element' );
+	}
+
 	my $self = {
+	    index_locations	=> $arg{index_locations},
 	    children	=> \@children,
 	    encoding	=> $arg{encoding},
 	    failures	=> 0,
+	    location	=> $arg{location},
 	    postderef	=> ( $arg{postderef} ? 1 : 0 ),
 	    source	=> $source,
 	};
@@ -62,8 +105,12 @@ $PPIx::QuoteLike::DEFAULT_POSTDEREF = 1;
 	    and warn "Initial match of $string\n";
 
 	# q<>, qq<>, qx<>
-	if ( $string =~ m/ \A \s* ( q [qx]? ) ( \s* ) ( \W ) /smxgc ) {
+	if ( $string =~ m/ \A \s* ( q [qx]? ) ( \s* ) ( . ) /smxgc ) {
 	    ( $type, $gap, $start_delim ) = ( $1, $2, $3 );
+	    not $gap
+		and $start_delim =~ m< \A \w \z >smx
+		and return $self->_link_elems( $self->_make_token(
+		    CLASS_UNKNOWN, $string, error => ILLEGAL_FIRST ) );
 	    $arg{trace}
 		and warn "Initial match '$type$start_delim'\n";
 	    $self->{interpolates} = 'qq' eq $type ||
@@ -93,20 +140,14 @@ $PPIx::QuoteLike::DEFAULT_POSTDEREF = 1;
 		$end_delim = '';
 	    }
 	    $self->{start} = [
-		PPIx::QuoteLike::Token::Delimiter->__new(
-		    content	=> $start_delim,
-		),
-		PPIx::QuoteLike::Token::Whitespace->__new(
-		    content	=> "\n",
-		),
+		$self->_make_token( CLASS_DELIMITER, $start_delim ),
+		$self->_make_token( CLASS_WHITESPACE, "\n" ),
 	    ];
+
+	    # Don't instantiate yet -- we'll do them at the end.
 	    $self->{finish} = [
-		PPIx::QuoteLike::Token::Delimiter->__new(
-		    content	=> $end_delim,
-		),
-		PPIx::QuoteLike::Token::Whitespace->__new(
-		    content	=> "\n",
-		),
+		[ CLASS_DELIMITER, $end_delim ],
+		[ CLASS_WHITESPACE, "\n" ],
 	    ];
 
 	# ``, '', "", <>
@@ -127,91 +168,89 @@ $PPIx::QuoteLike::DEFAULT_POSTDEREF = 1;
 	} else {
 	    $arg{trace}
 		and warn "No initial match\n";
-	    return $self->_link_elems( $self->_unknown(
-		    $string, ILLEGAL_FIRST ) );
+	    return $self->_link_elems( $self->_make_token(
+		    CLASS_UNKNOWN, $string, error => ILLEGAL_FIRST ) );
 	}
 
 	$self->{interpolates} = $self->{interpolates} ? 1 : 0;
 
 	$self->{type} = [
-	    PPIx::QuoteLike::Token::Structure->__new(
-		content	=> $type,
-	    ),
-	    length $gap ? PPIx::QuoteLike::Token::Whitespace->__new(
-		content	=> $gap,
-	    ) : ()
+	    $self->_make_token( CLASS_STRUCTURE, $type ),
+	    length $gap ?
+		$self->_make_token( CLASS_WHITESPACE, $gap ) :
+		(),
 	];
 	$self->{start} ||= [
-	    PPIx::QuoteLike::Token::Delimiter->__new(
-		content	=> $start_delim,
-	    ),
+	    $self->_make_token( CLASS_DELIMITER, $start_delim ),
 	];
 
 	$arg{trace}
 	    and warn "Without delimiters: '$content'\n";
 
+	# We accumulate data and manufacure tokens at the end to reduce
+	# the overhead involved in merging strings.
 	if ( $self->{interpolates} ) {
-	    {	# Single-iteration loop
+	    push @children, [ '' => '' ];	# Prime the pump
+	    while ( 1 ) {
 
 		if ( $content =~ m/ \G ( \\ [ULulQEF] ) /smxgc ) {
-		    push @children, PPIx::QuoteLike::Token::Control->__new(
-			content	=> "$1",		# Remove magic
-		    );
-		    redo;
-		}
-
-		if ( $content =~ m/ \G ( [\$\@] \#? \$* ) /smxgc ) {
+		    push @children, [ CLASS_CONTROL, "$1" ];
+		} elsif ( $content =~ m/ \G ( \\ N [{] ( [^}]+ ) [}] ) /smxgc ) {
+		    # Handle \N{...} separately because it can not
+		    # contain an interpolation even inside of an
+		    # otherwise-interpolating string. That is to say,
+		    # "\N{$foo}" is simply invalid, and does not even
+		    # try to interpolate $foo.  {
+		    # TODO use $re = _match_enclosed( '{' ); # }
+		    my ( $seq, $name ) = ( $1, $2 );
+		    # TODO The Regexp is certainly too permissive. For
+		    # the moment all I am doing is disallowing
+		    # interpolation.
+		    push @children, $name =~ m/ [\$\@] /smx ?
+			[ CLASS_UNKNOWN, $seq,
+			    error => "Unknown charname '$name'" ] :
+			[ CLASS_STRING, $seq ];
+		} elsif ( $content =~ m/ \G ( [\$\@] \#? \$* ) /smxgc ) {
 		    push @children, $self->_interpolation( "$1", $content );
-		    redo;
-		}
-
-		if ( $content =~ m/ \G ( \\ . | [^\\\$\@]+ ) /smxgc ) {
-		    my $content = $1;
-		    @children
-			and $children[-1]->isa(
-			    'PPIx::QuoteLike::Token::String' )
-			and $content = ( pop @children )->content() .
-		    $content;
-		    push @children, PPIx::QuoteLike::Token::String->__new(
-			content	=> $content,
-		    );
-		    redo;
-		}
-	    }
-
-	    # We might have consecutive strings if _interpolation()
-	    # generated a string rather than an interpolation. Merge
-	    # these.
-	    my @rslt;
-	    foreach my $elem ( @children ) {
-		if ( $elem->isa( 'PPIx::QuoteLike::Token::String' ) &&
-		    @rslt &&
-		    $rslt[-1]->isa( 'PPIx::QuoteLike::Token::String' )
-		) {
-		    push @rslt, PPIx::QuoteLike::Token::String->__new(
-			content	=> join( '', map { $_->content() } pop
-			    @rslt, $elem ),
-		    );
+		} elsif ( $content =~ m/ \G ( \\ . | [^\\\$\@]+ ) /smxgc ) {
+		    push @children, [ CLASS_STRING, "$1" ];
 		} else {
-		    push @rslt, $elem;
+		    last;
+		}
+	    } continue {
+		# We might have consecutive strings for various reasons.
+		# Merge these.
+		if ( CLASS_STRING eq $children[-1][0] &&
+		    CLASS_STRING eq $children[-2][0] ) {
+		    my $merge = pop @children;
+		    $children[-1][1] .= $merge->[1];
 		}
 	    }
-	    @children = @rslt;
+	    shift @children;	# remove the priming
+
+	    # Make the tokens, at long last.
+	    foreach ( @children ) {
+		$_ = $self->_make_token( @{ $_ } );
+	    }
 
 	} else {
 
 	    length $content
-		and push @children, PPIx::QuoteLike::Token::String->__new(
-		    content	=> $content,
-		);
+		and push @children, $self->_make_token(
+		    CLASS_STRING, $content );
 
 	}
 
-	$self->{finish} ||= [
-	    PPIx::QuoteLike::Token::Delimiter->__new(
-		content	=> $end_delim,
-	    ),
-	];
+	if ( $self->{finish} ) {
+	    # If we already have something here it is data, not objects.
+	    foreach ( @{ $self->{finish} } ) {
+		$_ = $self->_make_token( @{ $_ } );
+	    }
+	} else {
+	    $self->{finish} = [
+		$self->_make_token( CLASS_DELIMITER, $end_delim ),
+	    ];
+	}
 
 	ref $_[1]
 	    and pos( $_[1] ) = pos $string;
@@ -269,7 +308,7 @@ sub failures {
 sub find {
     my ( $self, $target ) = @_;
 
-    my $check = CODE eq ref $target ? $target :
+    my $check = CODE_REF eq ref $target ? $target :
     ref $target ? croak 'find() target may not be ' . ref $target :
     sub { $_[0]->isa( $target ) };
     my @found;
@@ -303,6 +342,64 @@ sub interpolates {
     return $self->{interpolates};
 }
 
+sub location {
+    my ( $self ) = @_;
+    return $self->type()->location();
+}
+
+sub _make_token {
+    my ( $self, $class, $content, %arg ) = @_;
+    my $token = $class->__new( content => $content, %arg );
+    CLASS_UNKNOWN eq $class
+	and $self->{failures}++;
+    $self->{index_locations}
+	and $self->_update_location( $token );
+    return $token;
+}
+
+sub _update_location {
+    my ( $self, $token ) = @_;
+    $token->{location}	# Idempotent
+	and return;
+    my $loc = $self->{_location} ||= do {
+	my %loc = (
+	    line_content	=> '',
+	    location		=> $self->{location},
+	);
+	if ( __instance( $self->{source}, 'PPI::Element' ) ) {
+	    $loc{location} ||= $self->{source}->location();
+	    if ( my $doc = $self->{source}->document() ) {
+		$loc{tab_width} = $doc->tab_width();
+	    }
+	}
+	$loc{tab_width} ||= 1;
+	\%loc;
+    };
+    $loc->{location}
+	or return;
+    $token->{location} = [ @{ $loc->{location} } ];
+    if ( defined( my $content = $token->content() ) ) {
+	if ( my $newlines = $content =~ tr/\n/\n/ ) {
+	    $loc->{location}[LOCATION_LINE] += $newlines;
+	    $loc->{location}[LOCATION_LOGICAL_LINE] += $newlines;
+	    $content =~ s/ .* \n //smx;
+	    $loc->{location}[LOCATION_CHARACTER] =
+		$loc->{location}[LOCATION_COLUMN] = 1;
+	    $loc->{line_content} = '';
+	}
+	$loc->{location}[LOCATION_CHARACTER] += length $content;
+	$loc->{line_content} .= $content;
+	local $Text::Tabs::tabstop = $loc->{tab_width};
+	$loc->{location}[LOCATION_COLUMN] = 1 + length Text::Tabs::expand(
+	    $loc->{line_content} );
+    }
+    return;
+}
+
+sub parent {
+    return;
+}
+
 sub perl_version_introduced {
     my ( $self ) = @_;
     return List::Util::max( grep { defined $_ } MINIMUM_PERL,
@@ -358,6 +455,11 @@ sub start {
     return $self->{start}[ $inx || 0 ];
 }
 
+sub top {
+    my ( $self ) = @_;
+    return $self;
+}
+
 sub type {
     my ( $self, $inx ) = @_;
     $self->{type}
@@ -375,8 +477,6 @@ sub variables {
 
     my %var;
     foreach my $kid ( $self->children() ) {
-	$kid->can( 'variables' )
-	    or next;
 	foreach my $sym ( $kid->variables() ) {
 	    $var{$sym} = 1;
 	}
@@ -482,48 +582,42 @@ sub __decode {
 
     my %special = (
 	'$$'	=> sub {	# Process ID.
-	    my ( $content ) = @_;
-	    return PPIx::QuoteLike::Token::Interpolation->__new(
-		content	=> $content,
-	    );
+	    my ( undef, $sigil ) = @_;
+	    return [ CLASS_INTERPOLATION, $sigil ];
 	},
 	'$'	=> sub {	# Called if we find (e.g.) '$@'
-	    my ( $content ) = @_;
-	    $_[1] =~ m/ \G ( [\@] ) /smxgc
+	    my ( undef, $sigil ) = @_;
+	    $_[2] =~ m/ \G ( [\@] ) /smxgc
 		or return;
-	    return PPIx::QuoteLike::Token::Interpolation->__new(
-		content	=> "$content$1",
-	    );
+	    return [ CLASS_INTERPOLATION, "$sigil$1" ];
 	},
 	'@'	=> sub {	# Called if we find '@@'.
-	    my ( $content ) = @_;
-	    return PPIx::QuoteLike::Token::String->__new(
-		content	=> $content,
-	    );
+	    my ( undef, $sigil ) = @_;
+	    return [ CLASS_STRING, $sigil ];
 	},
     );
 
     sub _interpolation {	## no critic (RequireArgUnpacking)
 	my ( $self, $sigil ) = @_;
+	# Argument $_[2] is $content, but we can't unpack it because we
+	# need the caller to see any changes to pos().
 
 	if ( $_[2] =~ m/ \G (?= \{ ) /smxgc ) {
+	    # variable name enclosed in {}
 	    my $delim_re = _match_enclosed( qw< { > );
 	    $_[2] =~ m/ \G ( $delim_re ) /smxgc
-		and return PPIx::QuoteLike::Token::Interpolation->__new(
-		    content	=> "$sigil$1",
-		);
+		and return [ CLASS_INTERPOLATION, "$sigil$1" ];
 	    $_[2] =~ m/ \G ( .* ) /smxgc
-		and return $self->_unknown( "$sigil$1", MISMATCHED_DELIM );
+		and return [ CLASS_UNKNOWN, "$sigil$1",
+		    error => MISMATCHED_DELIM ];
 	    confess 'Failed to match /./';
 	}
 
 	if ( $_[2] =~ m< \G ( @{[ VARIABLE_RE ]} ) >smxgco
 	) {
+	    # variable name not enclosed in {}
 	    my $interp = "$sigil$1";
-	    my $deref = $self->postderef() ?
-		qr{ -> \@ | (?: -> )? }smx :
-		qr{ (?: -> )? }smx;
-	    while ( $_[2] =~ m/ \G  ( $deref ) (?= ( [[{] ) ) /smxgc ) { # }]
+	    while ( $_[2] =~ m/ \G  ( (?: -> )? ) (?= ( [[{] ) ) /smxgc ) { # }]
 		my $lead_in = $1;
 		my $delim_re = _match_enclosed( $2 );
 		if ( $_[2] =~ m/ \G ( $delim_re ) /smxgc ) {
@@ -531,28 +625,25 @@ sub __decode {
 		} else {
 		    $_[2] =~ m/ ( .* ) /smxgc;
 		    return (
-			PPIx::QuoteLike::Token::Interpolation->__new(
-			    content	=> $interp,
-			),
-			$self->_unknown( "$1", MISMATCHED_DELIM ),
+			[ CLASS_INTERPOLATION, $interp ],
+			[ CLASS_UNKNOWN, "$1", error => MISMATCHED_DELIM ],
 		    );
 		}
 	    }
 
-	    # Postfix dereferencing
-	    $self->postderef()
-		and $_[2] =~ m/ \G ( -> (?: \$ \# | [\$\@] ) [*] ) /smxgc
-		and $interp .= $1;
+	    if ( $self->postderef()
+		    and defined( my $deref = _match_postderef( $_[2] ) ) ) {
+		$interp .= $deref;
+	    }
 
-	    return PPIx::QuoteLike::Token::Interpolation->__new(
-		content	=> $interp,
-	    );
+	    return [ CLASS_INTERPOLATION, $interp ];
 	}
 
 	my $code;
 	$code = $special{$sigil}
-	    and my $elem = $code->( $sigil, $_[2] )
-	    or return $self->_unknown( $sigil, 'Sigil without interpolation' );
+	    and my $elem = $code->( $self, $sigil, $_[2] )
+	    or return [ CLASS_UNKNOWN, $sigil,
+		error => 'Sigil without interpolation' ];
 
 	return $elem;
     }
@@ -654,6 +745,37 @@ sub _link_elems {
     }
 }
 
+{
+    my %allow_subscr	= map { $_ => 1 } qw{ % @ };
+
+    # Match a postfix deref at the current position in the argument. If
+    # a match occurs it is returned, and the current position is
+    # updated. If not, nothing is returned, and the current position in
+    # the argument remains unchanged.
+    # This would all be much easier if I could count on Perl 5.10
+    sub _match_postderef {	## no critic (RequireArgUnpacking)
+	my $pos = pos $_[0];
+	$_[0] =~ m/ \G ( -> ) ( \$ \# | [\$\@%&*] ) /smxgc
+	    or return;
+	my $match = "$1$2";
+	my $sigil = $2;
+	$_[0] =~ m/ \G ( [*] ) /smxgc
+	    and return "$match$1";
+
+	if (
+	    $allow_subscr{$sigil} &&
+	    $_[0] =~ m/ \G (?= ( [[{] ) ) /smxgc	# }]
+	) {
+	    my $re = _match_enclosed( "$1" );
+	    $_[0] =~ m/ \G $re /smxgc
+		and return "$match$1";
+	}
+
+	pos $_[0] = $pos;
+	return;
+    }
+}
+
 sub _stringify_source {
     my ( $self, $string, %opt ) = @_;
 
@@ -705,15 +827,6 @@ sub _stringify_source {
     return;
 }
 
-sub _unknown {
-    my ( $self, $content, $error ) = @_;
-    $self->{failures}++;
-    return PPIx::QuoteLike::Token::Unknown->__new(
-	content	=> $content,
-	error	=> $error,
-    );
-}
-
 sub _unquote {
     my ( $string ) = @_;
     $string =~ s/ \A ['"] //smx
@@ -746,6 +859,12 @@ reasonably like string literals. Its real reason for being is to find
 interpolated variables for L<Perl::Critic|Perl::Critic> policies and
 similar code.
 
+=head1 INHERITANCE
+
+C<PPIx::QuoteLike> is not descended from any other class.
+
+C<PPIx::QuoteLike> has no descendants.
+
 =head1 METHODS
 
 This class supports the following public methods:
@@ -788,6 +907,20 @@ If the C<$source> is a C<PPI::Element>, this encoding is used only if
 the document that contains the element has neither a byte order mark nor
 C<'use utf8'>.
 
+=item index_locations
+
+This Boolean argument determines whether the locations of the tokens
+should be computed. It defaults to true if the C<$source> argument is a
+L<PPI::Element|PPI::Element> or if the C<location> argument was
+provided, and false otherwise.
+
+=item location
+
+This argument is a reference to an array compatible with that returned
+by the L<PPI::Element|PPI::Element> location() method. It defaults to
+the location of the C<$source> argument if that was a
+L<PPI::Element|PPI::Element>, otherwise no locations will be available.
+
 =item postderef
 
 This Boolean argument determines whether postfix dereferencing is
@@ -827,6 +960,11 @@ This method returns all child elements. Children do not include the
 L<type()|/type>, or the L<start()|/start> or L<finish()|/finish>
 delimiters.
 
+=head2 column_number
+
+This method returns the column number of the first character in the
+element, or C<undef> if that can not be determined.
+
 =head2 content
 
  say $str->content();
@@ -915,6 +1053,36 @@ a false value if it does not. This does B<not> indicate whether any
 interpolation actually takes place, only whether the string is
 double-quotish or single-quotish.
 
+=head2 line_number
+
+This method returns the line number of the first character in the
+element, or C<undef> if that can not be determined.
+
+=head2 location
+
+This method returns a reference to an array describing the position of
+the string, or C<undef> if the location is unavailable.
+
+The array is compatible with the corresponding
+L<PPI::Element|PPI::Element> method.
+
+=head2 logical_filename
+
+This method returns the logical file name (taking C<#line> directives
+into account) of the file containing first character in the element, or
+C<undef> if that can not be determined.
+
+=head2 logical_line_number
+
+This method returns the logical line number (taking C<#line> directives
+into account) of the first character in the element, or C<undef> if that
+can not be determined.
+
+=head2 parent
+
+This method returns nothing, since the invocant is only used at the top
+of the object hierarchy.
+
 =head2 perl_version_introduced
 
 This method returns the maximum value of C<perl_version_introduced>
@@ -967,6 +1135,30 @@ If called in list context you get the whole array. If called in scalar
 context you get the element whose index is given in the argument, or
 element zero if no argument is specified.
 
+=head2 statement
+
+This method returns the L<PPI::Statement|PPI::Statement> that
+contains this string, or nothing if the statement can not be
+determined.
+
+In general this method will return something only under the following
+conditions:
+
+=over
+
+=item * The string is contained in a L<PPIx::QuoteLike|PPIx::QuoteLike> object;
+
+=item * That object was initialized from a L<PPI::Element|PPI::Element>;
+
+=item * The L<PPI::Element|PPI::Element> is contained in a statement.
+
+=back
+
+=head2 top
+
+This method returns the top of the hierarchy -- in this case, the
+invocant.
+
 =head2 type
 
  my $type = $str->type();
@@ -993,6 +1185,12 @@ returned only once, and they are returned in no particular order. If the
 object does not represent a string that interpolates, nothing is
 returned.
 
+=head2 visual_column_number
+
+This method returns the visual column number (taking tabs into account)
+of the first character in the element, or C<undef> if that can not be
+determined.
+
 =head1 RESTRICTIONS
 
 By the nature of this module, it is never going to get everything right.
@@ -1004,7 +1202,7 @@ another.
 Sometimes the introduction of new syntax changes the way a string is
 parsed. For example, the C<\F> (fold case) case control was introduced
 in Perl 5.15.8. But it did not represent a syntax error prior to that
-version of Perl, it was simply parsed as C<V>. So
+version of Perl, it was simply parsed as C<F>. So
 
  $ perl -le 'print "Foo\FBar"'
 
@@ -1026,16 +1224,15 @@ it out. I<Caveat user>.
 =head2 Non-Standard Syntax
 
 There are modules out there that alter the syntax of Perl. If the syntax
-of a regular expression is altered, this module has no way to understand
+of a quote-like string is altered, this module has no way to understand
 that it has been altered, much less to adapt to the alteration. The
 following modules are known to cause problems:
 
 L<Acme::PerlML|Acme::PerlML>, which renders Perl as XML.
 
-L<Data::PostfixDeref|Data::PostfixDeref>, which causes Perl to interpret
-suffixed empty brackets as dereferencing the thing they suffix, and
-which is inconsistent with the postfix dereference syntax introduced in
-5.19.5 and mainstreamed with 5.24.0.
+C<Data::PostfixDeref>, which causes Perl to interpret suffixed empty
+brackets as dereferencing the thing they suffix. This module by Ben
+Morrow (C<BMORROW>) appears to have been retracted.
 
 L<Filter::Trigraph|Filter::Trigraph>, which recognizes ANSI C trigraphs,
 allowing Perl to be written in the ISO 646 character set.
@@ -1045,7 +1242,7 @@ L<Perl6::Pugs|Perl6::Pugs>. Enough said.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1053,7 +1250,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
