@@ -5,11 +5,11 @@ use 5.006;
 use strict;
 use warnings;
 
-use Carp;
-
 use base qw{ PPIx::QuoteLike::Token };
 
-our $VERSION = '0.005';
+use PPIx::QuoteLike::Constant qw{ @CARP_NOT };
+
+our $VERSION = '0.010';
 
 
 1;
@@ -50,7 +50,7 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -58,7 +58,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
