@@ -8,34 +8,68 @@ use warnings;
 use base qw{ Exporter };
 
 use Carp;
-use PPIx::QuoteLike::Constant qw{ VARIABLE_RE };
+use PPIx::QuoteLike::Constant qw{
+    HAVE_PPIX_REGEXP
+    LOCATION_LINE
+    LOCATION_CHARACTER
+    LOCATION_COLUMN
+    LOCATION_LOGICAL_LINE
+    LOCATION_LOGICAL_FILE
+    VARIABLE_RE
+    @CARP_NOT
+};
 use Scalar::Util ();
 
 use constant LEFT_CURLY		=> q<{>;
 use constant RIGHT_CURLY	=> q<}>;
 
-our @CARP_NOT = qw{
-    PPIx::QuoteLike
-    PPIx::QuoteLike::Token
-    PPIx::QuoteLike::Token::Interpolation
+our @EXPORT_OK = qw{
+    column_number
+    is_ppi_quotelike_element
+    line_number
+    logical_filename
+    logical_line_number
+    statement
+    visual_column_number
+    __instance
+    __variables
 };
 
-our @EXPORT_OK = qw{ __variables };
+our $VERSION = '0.010';
 
-our $VERSION = '0.005';
-
-require PPIx::QuoteLike;
-
-# We can't depend on PPIx::Regexp without getting into a circular
-# dependency. I think. But we can sure use it if we can come by it.
-my $have_ppix_regexp = eval {
-    require PPIx::Regexp;
-    1;
-};
+sub column_number {
+    my ( $self ) = @_;
+    return ( $self->location() || [] )->[LOCATION_CHARACTER];
+}
 
 {
 
-    # TODO make these state varables one we can require Perl 5.10.
+    my @relevant_ppi_classes = qw{
+	PPI::Token::Quote
+	PPI::Token::QuoteLike::Backtick
+	PPI::Token::QuoteLike::Command
+	PPI::Token::QuoteLike::Readline
+	PPI::Token::HereDoc
+    };
+
+    sub is_ppi_quotelike_element {
+	my ( $elem ) = @_;
+
+	ref $elem
+	    or return;
+
+	Scalar::Util::blessed( $elem )
+	    or return;
+
+	foreach my $class ( @relevant_ppi_classes ) {
+	    $elem->isa( $class )
+		and return 1;
+	}
+
+	return;
+    }
+
+    # TODO make these state varables once we can require Perl 5.10.
     my $postderef = { map { $_ => 1 } qw{ @* %* } };
 
     my $cast_allowed_for_bare_bracketed_variable = {
@@ -44,13 +78,53 @@ my $have_ppix_regexp = eval {
     sub __variables {
 	my ( $ppi ) = @_;
 
+	# In case we need to manufacture any.
+	require PPIx::QuoteLike;
+
 	Scalar::Util::blessed( $ppi )
-	    and $ppi->isa( 'PPI::Node' )
-	    or croak 'Argument must be a PPI::Node';
+	    or croak 'Argument must be an object';
+
+	# TODO the following two lines are a crock, but there does not
+	# seem to be a good alternative. Bad alternatives:
+	# * Introduce PPIx::QuoteLike::Element. But it seems stupid to
+	#   introduce a class simply to mark these as members of the
+	#   PPIx::QuoteLike family.
+	#   If I go this way at all, PPIx::QuoteLike::Element should be
+	#   analogous to PPIx::Regexp::Element in that it carries at
+	#   least the navigational and Perl version methods.
+	# * Use DOES(). But that was not introduced until 5.10. So I
+	#   could:
+	#   - Depend on UNIVERSAL::DOES. This kindly steps aside if
+	#     UNIVERSAL::DOES() exists, but it seems stupid to introduce
+	#     a dependency that is only needed under really old Perls.
+	#   - Same as above, only make the dependence conditional on the
+	#     version of Perl. This may actually be the best
+	#     alternative, but it's still pretty crufty.
+	$ppi->isa( 'PPIx::QuoteLike' )
+	    and return $ppi->variables();
+	$ppi->isa( 'PPIx::QuoteLike::Token' )
+	    and return $ppi->variables();
 
 	my %var;
 
-	foreach my $sym ( @{ $ppi->find( 'PPI::Token::Symbol' ) || [] } ) {
+	$ppi->isa( 'PPIx::Regexp::Element' )
+	    and do {
+		foreach my $code ( @{ $ppi->find(
+		    'PPIx::Regexp::Token::Code' ) || [] } ) {
+		    foreach my $name ( __variables( $code->ppi() ) ) {
+			$var{ $name } = 1;
+		    }
+		}
+		return keys %var;
+	    };
+
+
+	$ppi->isa( 'PPI::Element' )
+	    or croak 'Argument must be a PPI::Element, ',
+		'PPIx::Regexp::Element, PPIx::QuoteLike, or ',
+		'PPIx::QuoteLike::Token';
+
+	foreach my $sym ( _find( $ppi, 'PPI::Token::Symbol' ) ) {
 	    # The problem we're solving here is that PPI parses postfix
 	    # dereference as though it makes reference to non-existent
 	    # punctuation variables '@*' or '%*'. The following
@@ -80,9 +154,7 @@ my $have_ppix_regexp = eval {
         # by a Symbol, so as long as nobody decides the '$#' cast causes
         # $elem->symbol() to return something other than '$foo', we're
         # cool.
-        foreach my $elem (
-            @{ $ppi->find( 'PPI::Token::ArrayIndex' ) || [] }
-        ) {
+        foreach my $elem ( _find( $ppi, 'PPI::Token::ArrayIndex' ) ) {
             my $name = $elem->content();
             $name =~ s/ \A \$ [#] /@/smx or next;
 	    $var{$name} = 1;
@@ -94,9 +166,7 @@ my $have_ppix_regexp = eval {
         # words in most Perl, we start at the top and work down. Perl
         # also handles punctuation variables specified this way, but
         # since PPI goes berserk when it sees this, we won't bother.
-        foreach my $elem (
-            @{ $ppi->find( 'PPI::Structure::Block' ) || [] }
-        ) {
+        foreach my $elem ( _find( $ppi, 'PPI::Structure::Block' ) ) {
 
             my $previous = $elem->sprevious_sibling()
                 or next;
@@ -153,14 +223,8 @@ my $have_ppix_regexp = eval {
 
 	# Yes, we might have nested string literals, like
 	# "... @{[ qq<$foo> ]} ..."
-	foreach my $class ( qw{
-		PPI::Token::Quote
-		PPI::Token::QuoteLike::Backtick
-		PPI::Token::QuoteLike::Command
-		PPI::Token::QuoteLike::Readline
-		PPI::Token::HereDoc
-	    } ) {
-	    foreach my $elem ( @{ $ppi->find( $class ) || [] } ) {
+	foreach my $class ( @relevant_ppi_classes ) {
+	    foreach my $elem ( _find( $ppi, $class ) ) {
 
 		my $ql = PPIx::QuoteLike->new( $elem )
 		    or next;
@@ -175,13 +239,13 @@ my $have_ppix_regexp = eval {
 	# By the same token we might have a regexp
 	# TODO for consistency's sake, give PPIx::Regexp a variables()
 	# method.
-	if ( $have_ppix_regexp ) {
+	if ( HAVE_PPIX_REGEXP ) {
 	    foreach my $class ( qw{
 		    PPI::Token::QuoteLike::Regexp
 		    PPI::Token::Regexp::Match
 		    PPI::Token::Regexp::Substitute
 		} ) {
-		foreach my $elem ( @{ $ppi->find( $class ) || [] } ) {
+		foreach my $elem ( _find( $ppi, $class ) ) {
 		    my $re = PPIx::Regexp->new( $elem )
 			or next;
 		    foreach my $code ( @{ $re->find(
@@ -198,6 +262,24 @@ my $have_ppix_regexp = eval {
     }
 }
 
+# We want __variables to work when passed a single token. So we go
+# through this to do what we wish PPI did -- return an array for a
+# PPI::Node, or return either the element itself or nothing otherwise.
+sub _find {
+    my ( $elem, $class ) = @_;
+    $elem->isa( 'PPI::Node' )
+	and return @{ $elem->find( $class ) || [] };
+    $elem->isa( $class )
+	and return $elem;
+    return;
+}
+
+sub __instance {
+    my ( $object, $class ) = @_;
+    Scalar::Util::blessed( $object ) or return;
+    return $object->isa( $class );
+}
+
 # The problem this solves is that PPI can parse '{_}' as containing a
 # PPI::Token::Magic (which is a PPI::Token::Symbol), not a
 # PPI::Token::Word. This code also returns true for '${_}', which is not
@@ -225,6 +307,39 @@ sub _is_bareword_subscript {
     return 1;
 }
 
+sub line_number {
+    my ( $self ) = @_;
+    return ( $self->location() || [] )->[LOCATION_LINE];
+}
+
+sub logical_filename {
+    my ( $self ) = @_;
+    return ( $self->location() || [] )->[LOCATION_LOGICAL_FILE];
+}
+
+sub logical_line_number {
+    my ( $self ) = @_;
+    return ( $self->location() || [] )->[LOCATION_LOGICAL_LINE];
+}
+
+sub statement {
+    my ( $self ) = @_;
+    my $top = $self->top()
+	or return;
+    $top->can( 'source' )
+	or return;
+    my $source = $top->source()
+	or return;
+    $source->can( 'statement' )
+	or return;
+    return $source->statement();
+}
+
+sub visual_column_number {
+    my ( $self ) = @_;
+    return ( $self->location() || [] )->[LOCATION_COLUMN];
+}
+
 # This handles two known cases where PPI misparses bracketed variable
 # names.
 # * $${foo} is parsed as '$$' when it is really a dereference of $foo.
@@ -317,6 +432,67 @@ did not seem to fit anywhere else.
 
 This module supports the following public subroutines:
 
+=head2 column_number
+
+This subroutine/method returns the column number of the first character
+in the element, or C<undef> if that can not be determined.
+
+=head2 is_ppi_quotelike_element
+
+This subroutine returns true if its argument is a
+L<PPI::Element|PPI::Element> that this package is capable of dealing
+with. That is, one of the following:
+
+    PPI::Token::Quote
+    PPI::Token::QuoteLike::Backtick
+    PPI::Token::QuoteLike::Command
+    PPI::Token::QuoteLike::Readline
+    PPI::Token::HereDoc
+
+It returns false for unblessed references and for non-references.
+
+=head2 line_number
+
+This subroutine/method returns the line number of the first character in
+the element, or C<undef> if that can not be determined.
+
+=head2 logical_filename
+
+This subroutine/method returns the logical file name (taking C<#line>
+directives into account) of the file containing first character in the
+element, or C<undef> if that can not be determined.
+
+=head2 logical_line_number
+
+This subroutine/method returns the logical line number (taking C<#line>
+directives into account) of the first character in the element, or
+C<undef> if that can not be determined.
+
+=head2 statement
+
+This subroutine/method returns the L<PPI::Statement|PPI::Statement> that
+contains this element, or nothing if the statement can not be
+determined.
+
+In general this method will return something only under the following
+conditions:
+
+=over
+
+=item * The element is contained in a L<PPIx::Regexp|PPIx::Regexp> object;
+
+=item * That object was initialized from a L<PPI::Element|PPI::Element>;
+
+=item * The L<PPI::Element|PPI::Element> is contained in a statement.
+
+=back
+
+=head2 visual_column_number
+
+This subroutine/method returns the visual column number (taking tabs
+into account) of the first character in the element, or C<undef> if that
+can not be determined.
+
 =head2 __variables
 
  say for __variables( PPI::Document->new( \'$foo' );
@@ -325,9 +501,10 @@ Despite the leading underscores, this exportable subroutine is public
 and supported. The underscores are so it will not appear to be public
 code to various tools when imported into other code.
 
-This subroutine takes as its only argument a L<PPI::Node|PPI::Node>, and
-returns the names of all variables found in that node, in no particular
-order. Scope is not taken into account.
+This subroutine takes as its only argument a
+L<PPI::Element|PPI::Element>, and returns the names of all variables
+found in that element, in no particular order. Scope is not taken into
+account.
 
 In addition to reporting variables parsed as such by L<PPI|PPI>, and
 various corner cases such as C<${]}> where PPI is blind to the use of
@@ -351,7 +528,7 @@ module, because of the possibility of a circular dependency.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -359,7 +536,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
